# pylint: skip-file
import json
from pathlib import Path

import pytest

import transformer.transform
from transformer.helpers import _DUMMY_HAR_DICT


class TestTransform:
    def test_it_returns_a_locustfile_string_given_scenario_path(self, tmp_path: Path):
        har_path = tmp_path / "some.har"
        with har_path.open("w") as file:
            json.dump(_DUMMY_HAR_DICT, file)
        locustfile_contents = str(transformer.transform.transform(har_path))
        try:
            compile(locustfile_contents, "locustfile.py", "exec")
        except Exception as exception:
            pytest.fail(f"Compiling locustfile failed. [{exception}].")



from pathlib import Path
from typing import cast

import tomlkit
from tomlkit.toml_document import TOMLDocument


def pyproject() -> TOMLDocument:
    with Path(__file__).parent.parent.joinpath("pyproject.toml").open() as f:
        pyproject = f.read()
    return tomlkit.parse(pyproject)


def version() -> str:
    return cast(str, pyproject()["tool"]["poetry"]["version"])



# -*- coding: utf-8 -*-
"""
Entrypoint for Transformer.
"""
from pathlib import Path
from typing import Sequence, Union

import transformer.python as py
from transformer.locust import locustfile
from transformer.plugins.contracts import OnTaskSequence
from transformer.scenario import Scenario


def transform(
    scenarios_path: Union[str, Path], plugins: Sequence[OnTaskSequence] = ()
) -> py.Program:
    return locustfile([Scenario.from_path(Path(scenarios_path), plugins)])
